@@ -1,6 +1,6 @@
 import os
+import re
 import subprocess as sb
-import time
 from pathlib import Path
 
 import click
@@ -17,15 +17,17 @@ from .constants import GODOT, KEYWORDS, PORT, VI
 
 STDOUT_MARKER_START = "----------------STDOUT-----------------------"
 STDOUT_MARKER_END = "----------------STDOUT END-----------------------"
+TIMEOUT = 0.2
 
 
 def script_dir():
     return str(Path(__file__).parent.resolve() / Path("gdserver.gd"))
 
+
 repl_script_path = script_dir()
 
 
-@click.group(cls=DefaultGroup, default='repl', default_if_no_args=True)
+@click.group(cls=DefaultGroup, default="run", default_if_no_args=True)
 def cli():
     pass
 
@@ -33,9 +35,14 @@ def cli():
 @cli.command(help="Launch the godot server and starts the repl")
 @click.option("--vi", is_flag=True, default=VI, help="Use vi mode")
 @click.option("--godot", default=GODOT, help="Path to godot executable")
-@click.option("--command", default="", help="Custom command to run the server script with")
-def repl(vi, godot, command):
-    print("Welcome to GDScript REPL. Hit Ctrl+C to exit. If you start having errors type 'clear'")
+@click.option(
+    "--command", default="", help="Custom command to run the server script with"
+)
+@click.option("--timeout", default=TIMEOUT, help="Time to wait for godot output")
+def run(vi, godot, command, timeout):
+    print(
+        "Welcome to GDScript REPL. Hit Ctrl+C to exit. If you start having errors type 'clear'"
+    )
     if not godot:
         return
     server = None
@@ -50,8 +57,13 @@ def repl(vi, godot, command):
     completer = WordCompleter(KEYWORDS, WORD=True)
     while True:
         try:
-            cmd = prompt(">>> ", vi_mode=vi, history=history,
-                         lexer=PygmentsLexer(GDScriptLexer), completer=completer)
+            cmd = prompt(
+                ">>> ",
+                vi_mode=vi,
+                history=history,
+                lexer=PygmentsLexer(GDScriptLexer),
+                completer=completer,
+            )
         except (EOFError, KeyboardInterrupt):
             client.close()
             break
@@ -70,17 +82,18 @@ def repl(vi, godot, command):
             print(resp)
 
         try:
-            server.expect(STDOUT_MARKER_START, 0.2)
-            time.sleep(0.1)
-            server.expect(STDOUT_MARKER_END, 0.1)
+            server.expect(STDOUT_MARKER_START, timeout=timeout)
+            server.expect(STDOUT_MARKER_END, timeout=timeout)
             output = server.before.decode()
             if output.strip():
                 print(output.strip())
         except pexpect.exceptions.TIMEOUT:
             pass
         try:
-            server.expect("SCRIPT ERROR: (.+)", 0.2)
-            print(server.match.group(1).decode())
+            server.expect(r"SCRIPT ERROR:(.+)", timeout=timeout)
+            error = server.match.group(1).decode().strip()
+            error = re.sub("\r\n" + r".*ERROR:.* Method failed\..*" + "\r\n.*", "", error)
+            print(error)
         except pexpect.exceptions.TIMEOUT:
             pass
 
@@ -89,7 +102,9 @@ def repl(vi, godot, command):
 @click.option("--vi", is_flag=True, default=VI, help="Use vi mode")
 @click.option("--port", default=PORT, help="Port to listen on")
 def client(vi, port):
-    print("Welcome to GDScript REPL. Hit Ctrl+C to exit. If you start having errors type 'clear'")
+    print(
+        "Welcome to GDScript REPL. Hit Ctrl+C to exit. If you start having errors type 'clear'"
+    )
     print("Not launching server..")
 
     # TODO avoid repeating this whole code here again
@@ -98,8 +113,13 @@ def client(vi, port):
     completer = WordCompleter(KEYWORDS, WORD=True)
     while True:
         try:
-            cmd = prompt(">>> ", vi_mode=vi, history=history,
-                         lexer=PygmentsLexer(GDScriptLexer), completer=completer)
+            cmd = prompt(
+                ">>> ",
+                vi_mode=vi,
+                history=history,
+                lexer=PygmentsLexer(GDScriptLexer),
+                completer=completer,
+            )
         except (EOFError, KeyboardInterrupt):
             client.close()
             break
